@@ -7,30 +7,34 @@
 #' @return concentric circles around origin
 #' @examples
 #' library(igraph)
-#' library(ggraph)
-
-#' g <- sample_gnp(10,0.4)
+#' g <- sample_gnp(10, 0.4)
 #'
 #' \dontrun{
-#' ggraph(g,layout = "centrality",centrality = degree(g))+
-#'   draw_circle(use = "cent")+
-#'   geom_edge_link()+
-#'   geom_node_point(shape = 21,fill = "grey25",size = 5)+
-#'   theme_graph()+
-#'   coord_fixed()
+#' library(ggraph)
+#' ggraph(g, layout = "centrality", centrality = degree(g)) +
+#'     draw_circle(use = "cent") +
+#'     geom_edge_link() +
+#'     geom_node_point(shape = 21, fill = "grey25", size = 5) +
+#'     theme_graph() +
+#'     coord_fixed()
 #' }
 #' @export
 #'
 
 draw_circle <- function(col = "#00BFFF", use = "focus", max.circle) {
   if (!requireNamespace("ggplot2", quietly = TRUE)) {
-    stop("ggplot2 needed for this function to work. Please install it.", call. = FALSE)
+    stop(
+      "ggplot2 needed for this function to work. Please install it.",
+      call. = FALSE
+    )
   }
   if (!use %in% c("focus", "cent")) {
     stop("use must be one of 'focus' or 'cent'")
   }
   if (use == "focus" && missing(max.circle)) {
-    stop("max.circle missing. Should be set to the max distance from focal node.")
+    stop(
+      "max.circle missing. Should be set to the max distance from focal node."
+    )
   }
   dat <- data.frame()
   if (use == "cent") {
@@ -46,7 +50,12 @@ draw_circle <- function(col = "#00BFFF", use = "focus", max.circle) {
       dat <- rbind(dat, tmp)
     }
   }
-  circs <- ggplot2::geom_path(data = dat, ggplot2::aes_(x = ~x, y = ~y, group = ~grp), col = col, alpha = 0.5)
+  circs <- ggplot2::geom_path(
+    data = dat,
+    ggplot2::aes_(x = ~x, y = ~y, group = ~grp),
+    col = col,
+    alpha = 0.5
+  )
   return(circs)
 }
 
@@ -62,30 +71,47 @@ draw_circle <- function(col = "#00BFFF", use = "focus", max.circle) {
 #' @return annotated concentric circles around origin
 #' @examples
 #' library(igraph)
-#' library(ggraph)
 #'
 #' g <- sample_gnp(10, 0.4)
 #' \dontrun{
+#' library(ggraph)
 #' ggraph(g, layout = "centrality", centrality = closeness(g)) +
-#'   draw_circle(use = "cent") +
-#'   annotate_circle(closeness(g), pos = "bottom", format = "scientific") +
-#'   geom_edge_link() +
-#'   geom_node_point(shape = 21, fill = "grey25", size = 5) +
-#'   theme_graph() +
-#'   coord_fixed()
+#'     draw_circle(use = "cent") +
+#'     annotate_circle(closeness(g), pos = "bottom", format = "scientific") +
+#'     geom_edge_link() +
+#'     geom_node_point(shape = 21, fill = "grey25", size = 5) +
+#'     theme_graph() +
+#'     coord_fixed()
 #' }
 #' @export
 #'
-annotate_circle <- function(cent, col = "#00BFFF", format = "", pos = "top", text_size = 3) {
+annotate_circle <- function(
+  cent,
+  col = "#00BFFF",
+  format = "",
+  pos = "top",
+  text_size = 3
+) {
   if (!requireNamespace("ggplot2", quietly = TRUE)) {
-    stop("ggplot2 needed for this function to work. Please install it.", call. = FALSE)
+    stop(
+      "ggplot2 needed for this function to work. Please install it.",
+      call. = FALSE
+    )
   }
   if (length(cent) == 1) {
     cent <- seq(1, cent, 1)
-    dat_annot <- data.frame(y = seq(0, 100, 20), x = 0, val = interpolate_cent(cent, seq(0, 100, 20)))
+    dat_annot <- data.frame(
+      y = seq(0, 100, 20),
+      x = 0,
+      val = interpolate_cent(cent, seq(0, 100, 20))
+    )
     dat_annot[["val"]] <- round(dat_annot[["val"]], 8)
   } else {
-    dat_annot <- data.frame(y = 100 - seq(0, 100, 20), x = 0, val = interpolate_cent(cent, seq(0, 100, 20)))
+    dat_annot <- data.frame(
+      y = 100 - seq(0, 100, 20),
+      x = 0,
+      val = interpolate_cent(cent, seq(0, 100, 20))
+    )
     dat_annot[["val"]] <- round(dat_annot[["val"]], 8)
   }
   vju <- 0
@@ -98,8 +124,11 @@ annotate_circle <- function(cent, col = "#00BFFF", format = "", pos = "top", tex
   }
 
   circs <- ggplot2::geom_text(
-    data = dat_annot, ggplot2::aes_(x = ~x, y = ~y, label = ~val),
-    col = col, vjust = vju, size = text_size
+    data = dat_annot,
+    ggplot2::aes_(x = ~x, y = ~y, label = ~val),
+    col = col,
+    vjust = vju,
+    size = text_size
   )
   return(circs)
 }
