@@ -23,9 +23,7 @@
 #' @export
 
 layout_with_eigen <- function(g, type = "laplacian", ev = "smallest") {
-  if (!igraph::is_igraph(g)) {
-    stop("g must be an igraph object")
-  }
+  ensure_igraph(g)
   if (!igraph::is_connected(g)) {
     stop("g must be connected")
   }
@@ -41,14 +39,14 @@ layout_with_eigen <- function(g, type = "laplacian", ev = "smallest") {
   }
   n <- igraph::vcount(g)
   if (type == "adjacency") {
-    A <- igraph::get.adjacency(g, type = "both")
+    A <- igraph::as_adj(g, type = "both")
   } else {
     A <- igraph::laplacian_matrix(g)
   }
   sA <- eigen(A)
   if (ev == "largest") {
     xy <- sA$vectors[, 1:2]
-  } else if (ev == "smallest" & type == "adjacency") {
+  } else if (ev == "smallest" && type == "adjacency") {
     xy <- sA$vectors[, (n - 1):n]
   } else {
     xy <- sA$vectors[, (n - 2):(n - 1)]
