@@ -1,131 +1,171 @@
 .init_layout <- function(g, D, mds, n, dim) {
-    if (!mds) {
-        return(matrix(stats::runif(n * dim, 0, 1), n, dim))
+  if (!mds) {
+    return(matrix(stats::runif(n * dim, 0, 1), n, dim))
+  } else {
+    rmat <- matrix(stats::runif(n * dim, -0.1, 0.1), n, dim)
+    if (n <= 100) {
+      return(igraph::layout_with_mds(g, dim = dim) + rmat)
     } else {
-        rmat <- matrix(stats::runif(n * dim, -0.1, 0.1), n, dim)
-        if (n <= 100) {
-            return(igraph::layout_with_mds(g, dim = dim) + rmat)
-        } else {
-            return(layout_with_pmds(g, D = D[, sample(1:n, 100)], dim = dim) + rmat)
-        }
+      return(layout_with_pmds(g, D = D[, sample(1:n, 100)], dim = dim) + rmat)
     }
+  }
 }
 
 .component_mover <- function(lg, p, bbox) {
-    curx <- 0
-    cury <- 0
-    maxy <- 0
-    for (comp in p) {
-        if (curx + max(lg[[comp]][, 1]) > bbox) {
-            curx <- 0
-            cury <- maxy + 1
-        }
-        lg[[comp]][, 1] <- lg[[comp]][, 1] + curx
-        lg[[comp]][, 2] <- lg[[comp]][, 2] + cury
-        curx <- max(lg[[comp]][, 1]) + 1
-        maxy <- max(c(maxy, max(lg[[comp]][, 2])))
+  curx <- 0
+  cury <- 0
+  maxy <- 0
+  for (comp in p) {
+    if (curx + max(lg[[comp]][, 1]) > bbox) {
+      curx <- 0
+      cury <- maxy + 1
     }
-    return(lg)
+    lg[[comp]][, 1] <- lg[[comp]][, 1] + curx
+    lg[[comp]][, 2] <- lg[[comp]][, 2] + cury
+    curx <- max(lg[[comp]][, 1]) + 1
+    maxy <- max(c(maxy, max(lg[[comp]][, 2])))
+  }
+  return(lg)
 }
 
-.component_layouter <- function(g, weights, comps, dim, mds, bbox, iter, tol, FUN, ...) {
-    # check which ... are arguments of FUN
-    FUN <- match.fun(FUN)
-    params_in <- list(...)
-    FUN_formals <- formals(FUN)
-    idx <- names(params_in) %in% names(FUN_formals)
-    params <- params_in[idx]
-    if ("dim" %in% names(FUN_formals)) {
-        params <- c(params, list(dim = params_in[["fixdim"]]))
-    }
+.component_layouter <- function(
+  g,
+  weights,
+  comps,
+  dim,
+  mds,
+  bbox,
+  iter,
+  tol,
+  FUN,
+  ...
+) {
+  # check which ... are arguments of FUN
+  FUN <- match.fun(FUN)
+  params_in <- list(...)
+  FUN_formals <- formals(FUN)
+  idx <- names(params_in) %in% names(FUN_formals)
+  params <- params_in[idx]
+  if ("dim" %in% names(FUN_formals)) {
+    params <- c(params, list(dim = params_in[["fixdim"]]))
+  }
 
-    lg <- list()
-    node_order <- c()
-    if (!is.null(weights) && any(!is.na(weights))) {
-        igraph::edge_attr(g, "_edgename") <- 1:igraph::ecount(g)
-        names(weights) <- 1:igraph::ecount(g)
-    }
+  lg <- list()
+  node_order <- c()
+  if (!is.null(weights) && any(!is.na(weights))) {
+    igraph::edge_attr(g, "_edgename") <- 1:igraph::ecount(g)
+    names(weights) <- 1:igraph::ecount(g)
+  }
 
-    for (i in 1:comps$no) {
-        idx <- which(comps$membership == i)
-        sg <- igraph::induced_subgraph(g, idx)
-        edge_idx <- igraph::edge_attr(g, "_edgename") %in% igraph::edge_attr(sg, "_edgename")
-        n <- igraph::vcount(sg)
-        node_order <- c(node_order, idx)
+  for (i in 1:comps$no) {
+    idx <- which(comps$membership == i)
+    sg <- igraph::induced_subgraph(g, idx)
+    edge_idx <- igraph::edge_attr(g, "_edgename") %in%
+      igraph::edge_attr(sg, "_edgename")
+    n <- igraph::vcount(sg)
+    node_order <- c(node_order, idx)
 
-        if (n == 1) {
-            lg[[i]] <- matrix(rep(0, dim), 1, dim, byrow = TRUE)
-        } else if (n == 2) {
-            lg[[i]] <- matrix(c(0, rep(0, dim - 1), 1, rep(0, dim - 1)), 2, dim, byrow = TRUE)
-            next()
-        } else {
-            if (!is.null(weights) && any(!is.na(weights))) {
-                D <- igraph::distances(sg, weights = weights[edge_idx])
-            } else {
-                D <- igraph::distances(sg, weights = weights)
-            }
-            W <- 1 / D^2
-            diag(W) <- 0
-
-            xinit <- .init_layout(sg, D, mds, n, dim)
-            if ("dim" %in% names(params)) {
-                xinit[, params[["dim"]]] <- params_in[["coord"]][idx]
-            }
-            params_FUN <- c(params, list(y = xinit, W = W, D = D, iter = iter, tol = tol))
-            lg[[i]] <- do.call(FUN, params_FUN) # FUN(xinit, W, D, iter, tol)
-        }
-    }
-    if (!"dim" %in% names(params)) {
-        lg <- lapply(lg, mv_to_null)
-        p <- order(comps$csize)
-        lg <- .component_mover(lg, p, bbox)
-    }
-    x <- do.call("rbind", lg)
-    x[order(node_order), , drop = FALSE]
-}
-
-.layout_with_stress_dim <- function(g, weights = NA, iter = 500, tol = 0.0001, mds = TRUE, bbox = 30, dim = 2) {
-    ensure_igraph(g)
-    if (!dim %in% c(2, 3)) {
-        stop("dim must be either 2 or 3")
-    }
-
-    oldseed <- get_seed()
-    set.seed(42) # stress is deterministic and produces the same result up to translation. This keeps the layout fixed
-    on.exit(restore_seed(oldseed))
-
-    comps <- igraph::components(g, "weak")
-    if (comps$no == 1) {
-        n <- igraph::vcount(g)
-
-        if (n == 1) {
-            return(matrix(rep(0, dim), 1, dim, byrow = TRUE))
-        } else if (n == 2) {
-            return(matrix(c(0, rep(0, dim - 1), 1, rep(0, dim - 2)), 2, dim, byrow = TRUE))
-        } else {
-            if (!is.null(weights) && any(!is.na(weights))) {
-                D <- igraph::distances(g, weights = weights)
-            } else {
-                D <- igraph::distances(g)
-            }
-            W <- 1 / D^2
-            diag(W) <- 0
-
-            xinit <- .init_layout(g, D, mds, n, dim)
-
-            if (dim == 2) {
-                return(stress_major(xinit, W, D, iter, tol))
-            } else {
-                return(stress_major3D(xinit, W, D, iter, tol))
-            }
-        }
+    if (n == 1) {
+      lg[[i]] <- matrix(rep(0, dim), 1, dim, byrow = TRUE)
+    } else if (n == 2) {
+      lg[[i]] <- matrix(
+        c(0, rep(0, dim - 1), 1, rep(0, dim - 1)),
+        2,
+        dim,
+        byrow = TRUE
+      )
+      next()
     } else {
-        layouter <- ifelse(dim == 2, stress_major, stress_major3D)
-        return(.component_layouter(
-            g = g, weights = weights, comps = comps, dim = dim, mds = mds,
-            bbox = bbox, iter = iter, tol = tol, FUN = layouter
-        ))
+      if (!is.null(weights) && any(!is.na(weights))) {
+        D <- igraph::distances(sg, weights = weights[edge_idx])
+      } else {
+        D <- igraph::distances(sg, weights = weights)
+      }
+      W <- 1 / D^2
+      diag(W) <- 0
+
+      xinit <- .init_layout(sg, D, mds, n, dim)
+      if ("dim" %in% names(params)) {
+        xinit[, params[["dim"]]] <- params_in[["coord"]][idx]
+      }
+      params_FUN <- c(
+        params,
+        list(y = xinit, W = W, D = D, iter = iter, tol = tol)
+      )
+      lg[[i]] <- do.call(FUN, params_FUN) # FUN(xinit, W, D, iter, tol)
     }
+  }
+  if (!"dim" %in% names(params)) {
+    lg <- lapply(lg, mv_to_null)
+    p <- order(comps$csize)
+    lg <- .component_mover(lg, p, bbox)
+  }
+  x <- do.call("rbind", lg)
+  x[order(node_order), , drop = FALSE]
+}
+
+.layout_with_stress_dim <- function(
+  g,
+  weights = NA,
+  iter = 500,
+  tol = 0.0001,
+  mds = TRUE,
+  bbox = 30,
+  dim = 2
+) {
+  ensure_igraph(g)
+  if (!dim %in% c(2, 3)) {
+    stop("dim must be either 2 or 3")
+  }
+
+  oldseed <- get_seed()
+  set.seed(42) # stress is deterministic and produces the same result up to translation. This keeps the layout fixed
+  on.exit(restore_seed(oldseed))
+
+  comps <- igraph::components(g, "weak")
+  if (comps$no == 1) {
+    n <- igraph::vcount(g)
+
+    if (n == 1) {
+      return(matrix(rep(0, dim), 1, dim, byrow = TRUE))
+    } else if (n == 2) {
+      return(matrix(
+        c(0, rep(0, dim - 1), 1, rep(0, dim - 2)),
+        2,
+        dim,
+        byrow = TRUE
+      ))
+    } else {
+      if (!is.null(weights) && any(!is.na(weights))) {
+        D <- igraph::distances(g, weights = weights)
+      } else {
+        D <- igraph::distances(g)
+      }
+      W <- 1 / D^2
+      diag(W) <- 0
+
+      xinit <- .init_layout(g, D, mds, n, dim)
+
+      if (dim == 2) {
+        return(stress_major(xinit, W, D, iter, tol))
+      } else {
+        return(stress_major3D(xinit, W, D, iter, tol))
+      }
+    }
+  } else {
+    layouter <- ifelse(dim == 2, stress_major, stress_major3D)
+    return(.component_layouter(
+      g = g,
+      weights = weights,
+      comps = comps,
+      dim = dim,
+      mds = mds,
+      bbox = bbox,
+      iter = iter,
+      tol = tol,
+      FUN = layouter
+    ))
+  }
 }
 
 
@@ -150,7 +190,6 @@
 #' @references Gansner, E. R., Koren, Y., & North, S. (2004). Graph drawing by stress majorization. *In International Symposium on Graph Drawing* (pp. 239-250). Springer, Berlin, Heidelberg.
 #' @examples
 #' library(igraph)
-#' library(ggraph)
 #' set.seed(665)
 #'
 #' g <- sample_pa(100, 1, 1, directed = FALSE)
@@ -160,14 +199,22 @@
 #'
 #' # use it with ggraph
 #' \dontrun{
+#' library(ggraph)
 #' ggraph(g, layout = "stress") +
 #'     geom_edge_link0(edge_width = 0.2, colour = "grey") +
 #'     geom_node_point(col = "black", size = 0.3) +
 #'     theme_graph()
 #' }
 #' @export
-layout_with_stress <- function(g, weights = NA, iter = 500, tol = 0.0001, mds = TRUE, bbox = 30) {
-    .layout_with_stress_dim(g, weights, iter, tol, mds, bbox, dim = 2)
+layout_with_stress <- function(
+  g,
+  weights = NA,
+  iter = 500,
+  tol = 0.0001,
+  mds = TRUE,
+  bbox = 30
+) {
+  .layout_with_stress_dim(g, weights, iter, tol, mds, bbox, dim = 2)
 }
 
 #------------------------------------------------------------------------------#
@@ -190,8 +237,15 @@ layout_with_stress <- function(g, weights = NA, iter = 500, tol = 0.0001, mds =
 #' @seealso [layout_stress]
 #' @references Gansner, E. R., Koren, Y., & North, S. (2004). Graph drawing by stress majorization. *In International Symposium on Graph Drawing* (pp. 239-250). Springer, Berlin, Heidelberg.
 #' @export
-layout_with_stress3D <- function(g, weights = NA, iter = 500, tol = 0.0001, mds = TRUE, bbox = 30) {
-    .layout_with_stress_dim(g, weights, iter, tol, mds, bbox, dim = 3)
+layout_with_stress3D <- function(
+  g,
+  weights = NA,
+  iter = 500,
+  tol = 0.0001,
+  mds = TRUE,
+  bbox = 30
+) {
+  .layout_with_stress_dim(g, weights, iter, tol, mds, bbox, dim = 3)
 }
 
 
@@ -221,34 +275,33 @@ layout_with_stress3D <- function(g, weights = NA, iter = 500, tol = 0.0001, mds
 #' @export
 
 layout_with_focus <- function(g, v, weights = NA, iter = 500, tol = 0.0001) {
-    ensure_igraph(g)
-    ensure_connected(g)
-    if (missing(v)) {
-        stop("v missing without a default")
-    }
-    oldseed <- get_seed()
-    set.seed(42) # stress is deterministic and produces same result up to translation. This keeps the layout fixed
-    on.exit(restore_seed(oldseed))
+  ensure_igraph(g)
+  ensure_connected(g)
+  if (missing(v)) {
+    stop("v missing without a default")
+  }
+  oldseed <- get_seed()
+  set.seed(42) # stress is deterministic and produces same result up to translation. This keeps the layout fixed
+  on.exit(restore_seed(oldseed))
 
-    n <- igraph::vcount(g)
-    D <- igraph::distances(g, weights = weights)
-    W <- 1 / D^2
-    diag(W) <- 0
+  n <- igraph::vcount(g)
+  D <- igraph::distances(g, weights = weights)
+  W <- 1 / D^2
+  diag(W) <- 0
 
-    Z <- matrix(0, n, n)
-    Z[v, ] <- Z[, v] <- 1
-    Z <- W * Z
+  Z <- matrix(0, n, n)
+  Z[v, ] <- Z[, v] <- 1
+  Z <- W * Z
 
+  rmat <- matrix(stats::runif(n * 2, -0.1, 0.1), n, 2)
+  xinit <- igraph::layout_with_mds(g) + rmat
 
-    rmat <- matrix(stats::runif(n * 2, -0.1, 0.1), n, 2)
-    xinit <- igraph::layout_with_mds(g) + rmat
+  tseq <- seq(0, 1, 0.1)
+  x <- stress_focus(xinit, W, D, Z, tseq, iter, tol)
 
-    tseq <- seq(0, 1, 0.1)
-    x <- stress_focus(xinit, W, D, Z, tseq, iter, tol)
-
-    offset <- x[v, ]
-    x <- t(apply(x, 1, function(x) x - offset))
-    return(list(xy = x, distance = D[, v]))
+  offset <- x[v, ]
+  x <- t(apply(x, 1, function(x) x - offset))
+  return(list(xy = x, distance = D[, v]))
 }
 
 #------------------------------------------------------------------------------#
@@ -275,10 +328,10 @@ layout_with_focus <- function(g, v, weights = NA, iter = 500, tol = 0.0001) {
 #' @references Brandes, U., & Pich, C. (2011). More flexible radial layout. Journal of Graph Algorithms and Applications, 15(1), 157-173.
 #' @examples
 #' library(igraph)
-#' library(ggraph)
 #'
 #' g <- sample_gnp(10, 0.4)
 #' \dontrun{
+#' library(ggraph)
 #' ggraph(g, layout = "centrality", centrality = closeness(g)) +
 #'     draw_circle(use = "cent") +
 #'     geom_edge_link0() +
@@ -289,46 +342,57 @@ layout_with_focus <- function(g, v, weights = NA, iter = 500, tol = 0.0001) {
 
 #' @export
 #'
-layout_with_centrality <- function(g, cent, scale = TRUE, iter = 500, tol = 0.0001, tseq = seq(0, 1, 0.2)) {
-    ensure_igraph(g)
-    ensure_connected(g)
-    if (missing(cent)) {
-        stop("cent missing without a default")
-    }
-    oldseed <- get_seed()
-    set.seed(42) # stress is deterministic and produces same result up to translation. This keeps the layout fixed
-    on.exit(restore_seed(oldseed))
+layout_with_centrality <- function(
+  g,
+  cent,
+  scale = TRUE,
+  iter = 500,
+  tol = 0.0001,
+  tseq = seq(0, 1, 0.2)
+) {
+  ensure_igraph(g)
+  ensure_connected(g)
+  if (missing(cent)) {
+    stop("cent missing without a default")
+  }
+  oldseed <- get_seed()
+  set.seed(42) # stress is deterministic and produces same result up to translation. This keeps the layout fixed
+  on.exit(restore_seed(oldseed))
 
-    n <- igraph::vcount(g)
-    if (scale) {
-        cent <- scale_to_100(cent)
-    }
-    r <- unname(igraph::diameter(g) / 2 * (1 - ((cent - min(cent)) / (max(cent) - min(cent) + 1))))
+  n <- igraph::vcount(g)
+  if (scale) {
+    cent <- scale_to_100(cent)
+  }
+  r <- unname(
+    igraph::diameter(g) /
+      2 *
+      (1 - ((cent - min(cent)) / (max(cent) - min(cent) + 1)))
+  )
 
-    D <- igraph::distances(g, weights = NA)
-    W <- 1 / D^2
-    diag(W) <- 0
+  D <- igraph::distances(g, weights = NA)
+  W <- 1 / D^2
+  diag(W) <- 0
 
-    rmat <- matrix(stats::runif(n * 2, -0.1, 0.1), n, 2)
-    xinit <- igraph::layout_with_mds(g) + rmat
+  rmat <- matrix(stats::runif(n * 2, -0.1, 0.1), n, 2)
+  xinit <- igraph::layout_with_mds(g) + rmat
 
-    x <- stress_major(xinit, W, D, iter, tol)
-    x <- stress_radii(x, W, D, r, tseq)
+  x <- stress_major(xinit, W, D, iter, tol)
+  x <- stress_radii(x, W, D, r, tseq)
 
-    # move highest cent to 0,0
-    idx <- which.max(cent)[1]
-    offset <- x[idx, ]
+  # move highest cent to 0,0
+  idx <- which.max(cent)[1]
+  offset <- x[idx, ]
 
-    x <- t(apply(x, 1, function(x) x - offset))
-    if (scale) {
-        radii_new <- round(100 - cent, 8)
-        angles <- apply(x, 1, function(y) atan2(y[2], y[1]))
-        return(cbind(radii_new * cos(angles), radii_new * sin(angles)))
-    } else {
-        radii_new <- round(max(cent) - cent, 8)
-        angles <- apply(x, 1, function(y) atan2(y[2], y[1]))
-        return(cbind(radii_new * cos(angles), radii_new * sin(angles)))
-    }
+  x <- t(apply(x, 1, function(x) x - offset))
+  if (scale) {
+    radii_new <- round(100 - cent, 8)
+    angles <- apply(x, 1, function(y) atan2(y[2], y[1]))
+    return(cbind(radii_new * cos(angles), radii_new * sin(angles)))
+  } else {
+    radii_new <- round(max(cent) - cent, 8)
+    angles <- apply(x, 1, function(y) atan2(y[2], y[1]))
+    return(cbind(radii_new * cos(angles), radii_new * sin(angles)))
+  }
 }
 
 #------------------------------------------------------------------------------#
@@ -353,39 +417,56 @@ layout_with_centrality <- function(g, cent, scale = TRUE, iter = 500, tol = 0.00
 #' @return matrix of xy coordinates
 #' @references Gansner, E. R., Koren, Y., & North, S. (2004). Graph drawing by stress majorization. *In International Symposium on Graph Drawing* (pp. 239-250). Springer, Berlin, Heidelberg.
 #' @export
-layout_with_constrained_stress <- function(g, coord, fixdim = "x", weights = NA,
-                                           iter = 500, tol = 0.0001, mds = TRUE, bbox = 30) {
-    ensure_igraph(g)
+layout_with_constrained_stress <- function(
+  g,
+  coord,
+  fixdim = "x",
+  weights = NA,
+  iter = 500,
+  tol = 0.0001,
+  mds = TRUE,
+  bbox = 30
+) {
+  ensure_igraph(g)
 
-    oldseed <- get_seed()
-    set.seed(42) # stress is deterministic and produces same result up to translation. This keeps the layout fixed
-    on.exit(restore_seed(oldseed))
+  oldseed <- get_seed()
+  set.seed(42) # stress is deterministic and produces same result up to translation. This keeps the layout fixed
+  on.exit(restore_seed(oldseed))
 
-    fixdim <- match.arg(fixdim, c("x", "y"))
-    fixdim <- ifelse(fixdim == "x", 1, 2)
+  fixdim <- match.arg(fixdim, c("x", "y"))
+  fixdim <- ifelse(fixdim == "x", 1, 2)
 
-    if (missing(coord)) {
-        stop('"coord" is missing with no default.')
-    }
-    comps <- igraph::components(g, "weak")
-    if (comps$no == 1) {
-        if (igraph::vcount(g) == 1) {
-            return(matrix(c(0, 0), 1, 2))
-        } else {
-            D <- igraph::distances(g, weights = weights)
-            W <- 1 / D^2
-            diag(W) <- 0
-            n <- igraph::vcount(g)
-            xinit <- .init_layout(g, D, mds, n, dim = 2)
-            xinit[, fixdim] <- coord
-            return(constrained_stress_major(xinit, fixdim, W, D, iter, tol))
-        }
+  if (missing(coord)) {
+    stop('"coord" is missing with no default.')
+  }
+  comps <- igraph::components(g, "weak")
+  if (comps$no == 1) {
+    if (igraph::vcount(g) == 1) {
+      return(matrix(c(0, 0), 1, 2))
     } else {
-        return(.component_layouter(
-            g = g, weights = weights, comps = comps, dim = 2, mds = mds,
-            bbox = bbox, iter = iter, tol = tol, FUN = constrained_stress_major, fixdim = fixdim, coord = coord
-        ))
+      D <- igraph::distances(g, weights = weights)
+      W <- 1 / D^2
+      diag(W) <- 0
+      n <- igraph::vcount(g)
+      xinit <- .init_layout(g, D, mds, n, dim = 2)
+      xinit[, fixdim] <- coord
+      return(constrained_stress_major(xinit, fixdim, W, D, iter, tol))
     }
+  } else {
+    return(.component_layouter(
+      g = g,
+      weights = weights,
+      comps = comps,
+      dim = 2,
+      mds = mds,
+      bbox = bbox,
+      iter = iter,
+      tol = tol,
+      FUN = constrained_stress_major,
+      fixdim = fixdim,
+      coord = coord
+    ))
+  }
 }
 
 #' constrained stress layout in 3D
@@ -408,36 +489,53 @@ layout_with_constrained_stress <- function(g, coord, fixdim = "x", weights = NA,
 #' @return matrix of xyz coordinates
 #' @references Gansner, E. R., Koren, Y., & North, S. (2004). Graph drawing by stress majorization. *In International Symposium on Graph Drawing* (pp. 239-250). Springer, Berlin, Heidelberg.
 #' @export
-layout_with_constrained_stress3D <- function(g, coord, fixdim = "x", weights = NA,
-                                             iter = 500, tol = 0.0001, mds = TRUE, bbox = 30) {
-    ensure_igraph(g)
+layout_with_constrained_stress3D <- function(
+  g,
+  coord,
+  fixdim = "x",
+  weights = NA,
+  iter = 500,
+  tol = 0.0001,
+  mds = TRUE,
+  bbox = 30
+) {
+  ensure_igraph(g)
 
-    oldseed <- get_seed()
-    set.seed(42)
-    on.exit(restore_seed(oldseed))
+  oldseed <- get_seed()
+  set.seed(42)
+  on.exit(restore_seed(oldseed))
 
-    fixdim <- match.arg(fixdim, c("x", "y", "z"))
-    fixdim <- ifelse(fixdim == "x", 1, ifelse(fixdim == "y", 2, 3))
+  fixdim <- match.arg(fixdim, c("x", "y", "z"))
+  fixdim <- ifelse(fixdim == "x", 1, ifelse(fixdim == "y", 2, 3))
 
-    comps <- igraph::components(g, "weak")
-    if (comps$no == 1) {
-        if (igraph::vcount(g) == 1) {
-            return(matrix(c(0, 0, 0), 1, 3))
-        } else {
-            D <- igraph::distances(g, weights = weights)
-            W <- 1 / D^2
-            diag(W) <- 0
-            n <- igraph::vcount(g)
-            xinit <- .init_layout(g, D, mds, n, dim = 3)
-            xinit[, fixdim] <- coord
-            return(constrained_stress_major3D(xinit, fixdim, W, D, iter, tol))
-        }
+  comps <- igraph::components(g, "weak")
+  if (comps$no == 1) {
+    if (igraph::vcount(g) == 1) {
+      return(matrix(c(0, 0, 0), 1, 3))
     } else {
-        return(.component_layouter(
-            g = g, weights = weights, comps = comps, dim = 3, mds = mds,
-            bbox = bbox, iter = iter, tol = tol, FUN = constrained_stress_major3D, fixdim = fixdim, coord = coord
-        ))
+      D <- igraph::distances(g, weights = weights)
+      W <- 1 / D^2
+      diag(W) <- 0
+      n <- igraph::vcount(g)
+      xinit <- .init_layout(g, D, mds, n, dim = 3)
+      xinit[, fixdim] <- coord
+      return(constrained_stress_major3D(xinit, fixdim, W, D, iter, tol))
     }
+  } else {
+    return(.component_layouter(
+      g = g,
+      weights = weights,
+      comps = comps,
+      dim = 3,
+      mds = mds,
+      bbox = bbox,
+      iter = iter,
+      tol = tol,
+      FUN = constrained_stress_major3D,
+      fixdim = fixdim,
+      coord = coord
+    ))
+  }
 }
 
 #------------------------------------------------------------------------------#
@@ -469,45 +567,52 @@ layout_with_constrained_stress3D <- function(g, coord, fixdim = "x", weights = N
 #' fxy <- cbind(c(rep(0, 10), rep(1, 5)), NA)
 #' xy <- layout_with_fixed_coords(g, fxy)
 #' @export
-layout_with_fixed_coords <- function(g, coords, weights = NA,
-                                     iter = 500, tol = 0.0001, mds = TRUE, bbox = 30) {
-    ensure_igraph(g)
+layout_with_fixed_coords <- function(
+  g,
+  coords,
+  weights = NA,
+  iter = 500,
+  tol = 0.0001,
+  mds = TRUE,
+  bbox = 30
+) {
+  ensure_igraph(g)
 
-    oldseed <- get_seed()
-    set.seed(42) # stress is deterministic and produces same result up to translation. This keeps the layout fixed
-    on.exit(restore_seed(oldseed))
+  oldseed <- get_seed()
+  set.seed(42) # stress is deterministic and produces same result up to translation. This keeps the layout fixed
+  on.exit(restore_seed(oldseed))
 
-    if (missing(coords)) {
-        stop('"coords" is missing with no default.')
-    }
-    if (nrow(coords) != igraph::vcount(g) || ncol(coords) != 2) {
-        stop("coords has the wrong dimensions")
-    }
-    if (all(!is.na(coords))) {
-        warning("all coordinates fixed")
-        return(coords)
-    }
-    comps <- igraph::components(g, "weak")
-    if (comps$no == 1) {
-        if (igraph::vcount(g) == 1) {
-            return(matrix(c(0, 0), 1, 2))
-        } else {
-            D <- igraph::distances(g, weights = weights)
-            W <- 1 / D^2
-            diag(W) <- 0
-            n <- igraph::vcount(g)
-            xinit <- .init_layout(g, D, mds, n, dim = 2)
-            not_na_idx <- which(!is.na(coords), arr.ind = TRUE)
-            xinit[not_na_idx] <- coords[not_na_idx]
-            return(fixed_stress_major(xinit, coords, W, D, iter, tol))
-        }
+  if (missing(coords)) {
+    stop('"coords" is missing with no default.')
+  }
+  if (nrow(coords) != igraph::vcount(g) || ncol(coords) != 2) {
+    stop("coords has the wrong dimensions")
+  }
+  if (all(!is.na(coords))) {
+    warning("all coordinates fixed")
+    return(coords)
+  }
+  comps <- igraph::components(g, "weak")
+  if (comps$no == 1) {
+    if (igraph::vcount(g) == 1) {
+      return(matrix(c(0, 0), 1, 2))
     } else {
-        # return(.component_layouter(
-        #     g = g, weights = weights, comps = comps, dim = 2, mds = mds,
-        #     bbox = bbox, iter = iter, tol = tol, FUN = constrained_stress_major, fixdim = fixdim, coord = coord
-        # ))
-        stop("only connected graphs are supported")
+      D <- igraph::distances(g, weights = weights)
+      W <- 1 / D^2
+      diag(W) <- 0
+      n <- igraph::vcount(g)
+      xinit <- .init_layout(g, D, mds, n, dim = 2)
+      not_na_idx <- which(!is.na(coords), arr.ind = TRUE)
+      xinit[not_na_idx] <- coords[not_na_idx]
+      return(fixed_stress_major(xinit, coords, W, D, iter, tol))
     }
+  } else {
+    # return(.component_layouter(
+    #     g = g, weights = weights, comps = comps, dim = 2, mds = mds,
+    #     bbox = bbox, iter = iter, tol = tol, FUN = constrained_stress_major, fixdim = fixdim, coord = coord
+    # ))
+    stop("only connected graphs are supported")
+  }
 }
 
 #' radial focus group layout
@@ -532,18 +637,29 @@ layout_with_fixed_coords <- function(g, coords, weights = NA,
 #' grp <- as.character(rep(1:4, each = 5))
 #' layout_with_focus_group(g, v = 1, group = grp, shrink = 10)
 #' @export
-layout_with_focus_group <- function(g, v, group, shrink = 10, weights = NA, iter = 500, tol = 0.0001) {
-    ensure_igraph(g)
-    ensure_connected(g)
+layout_with_focus_group <- function(
+  g,
+  v,
+  group,
+  shrink = 10,
+  weights = NA,
+  iter = 500,
+  tol = 0.0001
+) {
+  ensure_igraph(g)
+  ensure_connected(g)
 
-    n_grp <- length(unique(group))
-    xy <- layout_with_focus(g, v)$xy
-    ints <- seq(0, 360, length.out = n_grp + 1)
+  n_grp <- length(unique(group))
+  xy <- layout_with_focus(g, v)$xy
+  ints <- seq(0, 360, length.out = n_grp + 1)
 
-    for (i in seq_len(n_grp)) {
-        xy[group == i, ] <- map_to_angle_range(xy[group == i, ], c(ints[i] + shrink, ints[i + 1] - shrink))
-    }
-    return(xy)
+  for (i in seq_len(n_grp)) {
+    xy[group == i, ] <- map_to_angle_range(
+      xy[group == i, ],
+      c(ints[i] + shrink, ints[i + 1] - shrink)
+    )
+  }
+  return(xy)
 }
 
 #------------------------------------------------------------------------------#
@@ -566,22 +682,25 @@ layout_with_focus_group <- function(g, v, group, shrink = 10, weights = NA, iter
 #' library(igraph)
 #' @export
 layout_with_centrality_group <- function(g, cent, group, shrink = 10, ...) {
-    ensure_igraph(g)
-    ensure_connected(g)
-    if (missing(group)) {
-        stop('argument "group" is missing with no default.')
-    }
-    if (missing(cent)) {
-        stop('argument "group" is missing with no default.')
-    }
-    n_grp <- length(unique(group))
-    xy <- layout_with_centrality(g, cent, ...)
-    ints <- seq(0, 360, length.out = n_grp + 1)
+  ensure_igraph(g)
+  ensure_connected(g)
+  if (missing(group)) {
+    stop('argument "group" is missing with no default.')
+  }
+  if (missing(cent)) {
+    stop('argument "group" is missing with no default.')
+  }
+  n_grp <- length(unique(group))
+  xy <- layout_with_centrality(g, cent, ...)
+  ints <- seq(0, 360, length.out = n_grp + 1)
 
-    for (i in seq_len(n_grp)) {
-        xy[group == i, ] <- map_to_angle_range(xy[group == i, ], c(ints[i] + shrink, ints[i + 1] - shrink))
-    }
-    return(xy)
+  for (i in seq_len(n_grp)) {
+    xy[group == i, ] <- map_to_angle_range(
+      xy[group == i, ],
+      c(ints[i] + shrink, ints[i + 1] - shrink)
+    )
+  }
+  return(xy)
 }
 
 #' @useDynLib graphlayouts, .registration = TRUE
